==> libreoffice-5.1.4.2.tar.xz: libreoffice-5.1.4.2/vcl/source/window/window3.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include "vcl/window.hxx"
#include "vcl/waitobj.hxx"
#include "vcl/button.hxx"

WaitObject::~WaitObject()
{
    if ( mpWindow )
        mpWindow->LeaveWait();
}

namespace vcl {

Size Window::GetOptimalSize() const
{
    return Size();
}

void Window::ImplAdjustNWFSizes()
{
    switch( GetType() )
    {
    case WINDOW_CHECKBOX:
        static_cast<CheckBox*>(this)->ImplSetMinimumNWFSize();
        break;
    case WINDOW_RADIOBUTTON:
        static_cast<RadioButton*>(this)->ImplSetMinimumNWFSize();
        break;
    default:
        {
            // iterate over children
            vcl::Window* pWin = GetWindow( GetWindowType::FirstChild );
            while( pWin )
            {
                pWin->ImplAdjustNWFSizes();
                pWin = pWin->GetWindow( GetWindowType::Next );
            }
        }
        break;
    }
}

} /* namespace vcl */


/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice_6.0.3.orig.tar.xz: libreoffice-6.0.3/vcl/source/window/window3.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include <vcl/window.hxx>
#include <vcl/waitobj.hxx>
#include <vcl/button.hxx>

WaitObject::~WaitObject()
{
    if ( mpWindow )
        mpWindow->LeaveWait();
}

namespace vcl {

Size Window::GetOptimalSize() const
{
    return Size();
}

void Window::ImplAdjustNWFSizes()
{
    switch( GetType() )
    {
    case WindowType::CHECKBOX:
        static_cast<CheckBox*>(this)->ImplSetMinimumNWFSize();
        break;
    case WindowType::RADIOBUTTON:
        static_cast<RadioButton*>(this)->ImplSetMinimumNWFSize();
        break;
    default:
        {
            // iterate over children
            vcl::Window* pWin = GetWindow( GetWindowType::FirstChild );
            while( pWin )
            {
                pWin->ImplAdjustNWFSizes();
                pWin = pWin->GetWindow( GetWindowType::Next );
            }
        }
        break;
    }
}

} /* namespace vcl */


/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
